pub enum CoverageRule {
MinCallsPerTool {
min: u64,
},
NoUncalledTools,
PercentCalled {
min_percent: f64,
},
}Expand description
Coverage validation rules for state-machine runs.
Variants
MinCallsPerTool
Require a minimum number of successful calls per tool.
NoUncalledTools
Require that all callable tools are called at least once.
PercentCalled
Require a minimum percentage of callable tools to be called.
Implementations
Sourceimpl CoverageRule
impl CoverageRule
Sourcepub fn min_calls_per_tool(min: u64) -> Self
pub fn min_calls_per_tool(min: u64) -> Self
Helper to enforce minimum calls per tool.
Sourcepub fn no_uncalled_tools() -> Self
pub fn no_uncalled_tools() -> Self
Helper to enforce no uncalled tools.
Sourcepub fn percent_called(min_percent: f64) -> Self
pub fn percent_called(min_percent: f64) -> Self
Helper to enforce minimum percentage of tools called.